#
# spec file for package python-PyHamcrest
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-PyHamcrest
Version:        2.0.3
Release:        2.3
Summary:        Hamcrest framework for matcher objects
License:        BSD-3-Clause
URL:            https://github.com/hamcrest/PyHamcrest
# PyPi is missing tests
#Source:         https://files.pythonhosted.org/packages/source/P/PyHamcrest/PyHamcrest-%%{version}.tar.gz
Source:         https://github.com/hamcrest/PyHamcrest/archive/V%{version}.tar.gz
Patch0:         0001-Add-boolean-matchers.patch
BuildRequires:  %{python_module hypothesis >= 1.11}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-hamcrest = %{version}
Obsoletes:      python-hamcrest < %{version}
BuildArch:      noarch
%python_subpackages

%description
Hamcrest framework for matcher objects.
PyHamcrest is a framework for writing matcher objects,
allowing you to declaratively define “match” rules.

%prep
%setup -q -n PyHamcrest-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/hamcrest

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/hamcrest
%{python_sitelib}/PyHamcrest-%{version}-py*.egg-info/

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr  7 2022 pgajdos@suse.com
- version update to 2.0.3
  * Features ^^^^^^^^
  - * Adds the tests to the sdist. Fixed by #150
    `#141 <https://github.com/hamcrest/PyHamcrest/issues/141>`_
  - * Update the CI to test Python 3.10
    `#160 <https://github.com/hamcrest/PyHamcrest/issues/160>`_
  - * Add pretty string representation for matchers objects
    `#170 <https://github.com/hamcrest/PyHamcrest/issues/170>`_
  * Bugfixes ^^^^^^^^
  - * Test coverage is now submitted to codecov.io.
    `#135 <https://github.com/hamcrest/PyHamcrest/issues/135>`_
  - Change to the ``has_entry()`` matcher - if exactly one key matches, but the value does not, report only the mismatching
    value.
    `#156 <https://github.com/hamcrest/PyHamcrest/issues/156>`_
  - * Fix is_() type annotations
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.0.2
  * Make hamcrest package PEP 561 compatible, i.e. supply type hints for external use.
  * Drop formal support for 2.x
  * Drop formal support for 3.x < 3.5
  * Made has_properties() report all mismatches, not just the first.
  * Silence warnings.
  * Type fixes.
  * Remove obsolete dependencies.
  * Add support up to Python 3.8
- Removed upstreamed patch pytest4-02.patch
* Thu Nov 21 2019 Matej Cepl <mcepl@suse.com>
- Remove pytest4.patch and replace it with pytest4-02.patch,
  which is the upstream gh#hamcrest/PyHamcrest#124 fixing
  compatibility with pytest 4+ officially. And of course, we
  don't have to massacre test files anymore.
* Tue Nov  5 2019 Matej Cepl <mcepl@suse.com>
- Run spec-cleaner
- Add pytest4.patch to make the testsuite actually really pass.
* Mon Nov  4 2019 Matej Cepl <mcepl@suse.com>
- Because of gh#hamcrest/PyHamcrest#123 we have to remove
  tests/hamcrest_unit_test/core/is{_test,instanceof_test}.py to
  make the test suite passing.
  Patch pytest4.patch has been removed, it was a step into dead
  end.
* Fri Jul 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Restrict pytest to 3.x as the newer does not work with release.
  In upstream git this was fixed by quite few commits so lets
  just wait for the release
* Wed Jul  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with new pytest:
  * pytest4.patch
* Wed Oct 17 2018 Tomáš Chvátal <tchvatal@suse.com>
- Provide and obsolete hamcrest
- Add patch from python-hamcrest which we now obsolete:
  * 0001-Add-boolean-matchers.patch
* Thu Oct 11 2018 Tomáš Chvátal <tchvatal@suse.com>
- Sort the deps with spec-cleaner
* Sat Oct  6 2018 ecsos@opensuse.org
- initial version 1.9.0
